@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -327,12 +330,16 @@ enum {
     kPowerStateSleepCanPowerOffBit = 3,                         /* supports power down sleep (ie PCI power off)*/
     kPowerStateSleepNoDPMSBit   = 4,                            /* Bug #2425210.  Do not use DPMS with this display.*/
     kPowerStateSleepWaketoDozeBit = 5,                          /* Supports Wake to Doze */
+    kPowerStateSleepWakeNeedsProbeBit = 6,                      /* Does not sense connection changes on wake */
+
     kPowerStateNeedsRefreshMask = (1L << kPowerStateNeedsRefresh),
     kPowerStateSleepAwareMask   = (1L << kPowerStateSleepAwareBit),
     kPowerStateSleepForbiddenMask = (1L << kPowerStateSleepForbiddenBit),
     kPowerStateSleepCanPowerOffMask = (1L << kPowerStateSleepCanPowerOffBit),
     kPowerStateSleepNoDPMSMask  = (1L << kPowerStateSleepNoDPMSBit),
     kPowerStateSleepWaketoDozeMask = (1L << kPowerStateSleepWaketoDozeBit),
+    kPowerStateSleepWakeNeedsProbeMask = (1L << kPowerStateSleepWakeNeedsProbeBit),
+
     kPowerStateSupportsReducedPower1Bit = 10,
     kPowerStateSupportsReducedPower2Bit = 11,
     kPowerStateSupportsReducedPower3Bit = 12,
